@@ -43,7 +43,7 @@ test_that("cross-validated covariance selector runs silently", {
       )
     ),
     cv_scheme = "v_fold", mc_split = 0.5, v_folds = 5,
-    center = TRUE, scale = FALSE, parallel = FALSE
+    parallel = FALSE
   ))
   expect_silent(cvCovEst(
     dat = dat,
@@ -78,7 +78,7 @@ test_that("cross-validated covariance selector runs silently", {
       )
     ),
     cv_scheme = "mc", mc_split = 0.5, v_folds = 5,
-    center = TRUE, scale = FALSE, parallel = FALSE
+    parallel = FALSE
   ))
   expect_silent(cvCovEst(
     dat = dat,
@@ -114,7 +114,7 @@ test_that("cross-validated covariance selector runs silently", {
     ),
     cv_loss = cvFrobeniusLoss, cv_scheme = "v_fold",
     mc_split = 0.5, v_folds = 5,
-    center = TRUE, scale = FALSE, parallel = FALSE
+    parallel = FALSE
   ))
   expect_silent(cvCovEst(
     dat = dat,
@@ -150,7 +150,7 @@ test_that("cross-validated covariance selector runs silently", {
     ),
     cv_loss = cvFrobeniusLoss, cv_scheme = "mc",
     mc_split = 0.5, v_folds = 5,
-    center = TRUE, scale = FALSE, parallel = FALSE
+    parallel = FALSE
   ))
   expect_silent(cvCovEst(
     dat = dat,
@@ -186,7 +186,7 @@ test_that("cross-validated covariance selector runs silently", {
     ),
     cv_loss = cvScaledMatrixFrobeniusLoss, cv_scheme = "v_fold",
     mc_split = 0.5, v_folds = 5,
-    center = TRUE, scale = FALSE, parallel = FALSE
+    parallel = FALSE
   ))
   expect_silent(cvCovEst(
     dat = dat,
@@ -222,7 +222,7 @@ test_that("cross-validated covariance selector runs silently", {
     ),
     cv_loss = cvScaledMatrixFrobeniusLoss, cv_scheme = "mc",
     mc_split = 0.5, v_folds = 5,
-    center = TRUE, scale = FALSE, parallel = FALSE
+    parallel = FALSE
   ))
   expect_silent(cvCovEst(
     dat = dat,
@@ -231,7 +231,7 @@ test_that("cross-validated covariance selector runs silently", {
       poetEst = list(lambda = c(0.1, 0.2), k = c(1L, 2L))
     ),
     cv_scheme = "v_fold", mc_split = 0.5, v_folds = 5,
-    center = TRUE, scale = FALSE, parallel = FALSE
+    parallel = FALSE
   ))
   expect_silent(cvCovEst(
     dat = dat,
@@ -243,64 +243,10 @@ test_that("cross-validated covariance selector runs silently", {
       )
     ),
     cv_scheme = "v_fold", mc_split = 0.5, v_folds = 5,
-    center = TRUE, scale = FALSE, parallel = FALSE
+    parallel = FALSE
   ))
 })
 
-test_that("cvCovEst automatically centers non-centered data", {
-  expect_silent(cvCovEst(
-    dat = dat,
-    estimators = c(
-      linearShrinkEst, linearShrinkLWEst,
-      thresholdingEst, sampleCovEst, bandingEst,
-      taperingEst, nlShrinkLWEst, denseLinearShrinkEst,
-      scadEst, poetEst, robustPoetEst, adaptiveLassoEst
-    ),
-    estimator_params = list(
-      linearShrinkEst = list(alpha = c(0.1, 0.9)),
-      thresholdingEst = list(gamma = c(0.2, 2)),
-      bandingEst = list(k = c(1L, 5L)),
-      taperingEst = list(k = c(2L, 6L)),
-      scadEst = list(lambda = c(0.1, 0.2)),
-      poetEst = list(lambda = c(0.1, 0.2), k = c(1L, 2L)),
-      robustPoetEst = list(
-        lambda = c(0.1, 0.2), k = c(1L, 2L),
-        var_est = c("sample")
-      ),
-      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5))
-    ),
-    cv_scheme = "v_fold", mc_split = 0.5, v_folds = 5,
-    center = TRUE, scale = FALSE, parallel = FALSE
-  ))
-  expect_message(
-    cvCovEst(
-      dat = dat,
-      estimators = c(
-        linearShrinkEst, linearShrinkLWEst,
-        thresholdingEst, sampleCovEst, bandingEst,
-        taperingEst, nlShrinkLWEst, denseLinearShrinkEst,
-        scadEst, poetEst, robustPoetEst, adaptiveLassoEst
-      ),
-      estimator_params = list(
-        linearShrinkEst = list(alpha = c(0.1, 0.9)),
-        thresholdingEst = list(gamma = c(0.2, 2)),
-        bandingEst = list(k = c(1L, 5L)),
-        taperingEst = list(k = c(2L, 6L)),
-        scadEst = list(lambda = c(0.1, 0.2)),
-        poetEst = list(lambda = c(0.1, 0.2), k = c(1L, 2L)),
-        robustPoetEst = list(
-          lambda = c(0.1, 0.2), k = c(1L, 2L),
-          var_est = c("sample")
-        ),
-        adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5))
-      ),
-      cv_scheme = "v_fold", mc_split = 0.5, v_folds = 5,
-      center = FALSE, scale = FALSE, parallel = FALSE
-    ),
-    "The columns of argument `dat` have been centered automatically"
-  )
-})
-
 test_that("cvCovEst's outputs are of the correct dimensions", {
 
   cv_ov_est_fit <- cvCovEst(
@@ -325,7 +271,7 @@ test_that("cvCovEst's outputs are of the correct dimensions", {
       adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5))
     ),
     cv_scheme = "v_fold", mc_split = 0.5, v_folds = 5,
-    center = TRUE, scale = FALSE, parallel = FALSE
+    parallel = FALSE
   )
   expect_true(length(cv_ov_est_fit) == 5)
   expect_true(ncol(cv_ov_est_fit$risk_df) == 3)
@@ -357,7 +303,7 @@ test_that("Parallelization works", {
       adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5))
     ),
     cv_scheme = "v_fold", mc_split = 0.5, v_folds = 5,
-    center = TRUE, scale = FALSE, parallel = TRUE
+    parallel = TRUE
   ))
   expect_silent(cvCovEst(
     dat = dat,
@@ -381,7 +327,7 @@ test_that("Parallelization works", {
       adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5))
     ),
     cv_scheme = "mc", mc_split = 0.5, v_folds = 5,
-    center = TRUE, scale = FALSE, parallel = TRUE
+    parallel = TRUE
   ))
   expect_silent(cvCovEst(
     dat = dat,
@@ -406,7 +352,7 @@ test_that("Parallelization works", {
     ),
     cv_loss = cvFrobeniusLoss, cv_scheme = "v_fold",
     mc_split = 0.5, v_folds = 5,
-    center = TRUE, scale = FALSE, parallel = TRUE
+    parallel = TRUE
   ))
   expect_silent(cvCovEst(
     dat = dat,
@@ -431,7 +377,7 @@ test_that("Parallelization works", {
     ),
     cv_loss = cvFrobeniusLoss, cv_scheme = "mc",
     mc_split = 0.5, v_folds = 5,
-    center = TRUE, scale = FALSE, parallel = TRUE
+    parallel = TRUE
   ))
   expect_silent(cvCovEst(
     dat = dat,
@@ -456,6 +402,6 @@ test_that("Parallelization works", {
     ),
     cv_loss = cvScaledMatrixFrobeniusLoss, cv_scheme = "mc",
     mc_split = 0.5, v_folds = 5,
-    center = TRUE, scale = FALSE, parallel = TRUE
+    parallel = TRUE
   ))
 })
